Sudocabulary
=============

.. image:: https://badge.fury.io/py/sudocabulary.svg
    :target: https://badge.fury.io/py/sudocabulary
.. image:: https://landscape.io/github/badarsh2/Sudocabulary/master/landscape.svg?style=flat
   :target: https://landscape.io/github/badarsh2/Sudocabulary/master
   :alt: Code Health\\
   
Want to combine your love for terminal with the love for learning English Vocabulary? Want a smart way to memorize flash card words for exams like GRE?

Look no further, just execute this command:

.. code-block:: bash

    curl https://raw.githubusercontent.com/badarsh2/Sudocabulary/master/script.sh | bash

Or you can also install it through pip

.. code-block:: bash

    sudo pip install sudocabulary --upgrade

Requirements for pip installation
----------------------------------

-   python>=2.7

Preview
------------------
.. image:: https://raw.githubusercontent.com/badarsh2/Sudocabulary/master/sample.png
    :alt: Sample Screenshot
    :width: 100%
    :align: center

How to Contribute
-----------------

If you have any improvements for the project feel free to make a PULL REQUEST.

Collaborators
--------------
`B Adarsh <https://github.com/badarsh2>`_
`Lakshmanaram <https://github.com/lakshmanaram>`_
`Srivatsan Ramesh <https://github.com/srivatsan-ramesh>`_